pub struct AutomationEventList(/* private fields */);Implementations
Sourceimpl AutomationEventList
impl AutomationEventList
Sourcepub unsafe fn unwrap(self) -> AutomationEventList
pub unsafe fn unwrap(self) -> AutomationEventList
Take the raw ffi type. Must manually free memory by calling the proper unload function
Sourceimpl AutomationEventList
impl AutomationEventList
Sourcepub fn to_raw(self) -> AutomationEventList
pub fn to_raw(self) -> AutomationEventList
returns the unwrapped raylib-sys object
Sourcepub unsafe fn from_raw(raw: AutomationEventList) -> AutomationEventList
pub unsafe fn from_raw(raw: AutomationEventList) -> AutomationEventList
converts raylib-sys object to a “safe” version. Make sure to call this function from the thread the resource was created.
Sourceimpl AutomationEventList
impl AutomationEventList