Structs
- Audio
Stream Processor Callback - This struct encapsulates a rust callback
and guarantees the lifetime to be long enough (’a)
(once
get_as_user_datais called, it the struct should not be moved again! -> use Pin<..>) - SetLog
Error
Enums
Functions
- attach_
audio_ stream_ processor_ to_ music - custom_
trace_ ⚠log_ callback - set_
audio_ stream_ callback - Audio thread callback to request new data
- set_
load_ file_ data_ callback - Set custom file binary data loader
- set_
load_ file_ text_ callback - Set custom file text data loader
- set_
save_ file_ data_ callback - Set custom file binary data saver
- set_
save_ file_ text_ callback - Set custom file text data saver
- set_
trace_ log_ callback - Set custom trace log