set_load_file_text_callback

Function set_load_file_text_callback 

pub fn set_load_file_text_callback<'a>(
    cb: fn(&str) -> String,
) -> Result<(), SetLogError<'a>>
Set custom file text data loader

Whatever you return from your callback will be intentionally leaked as Raylib is relied on to free it.