Module core

Module core 

Structs

RaylibBuilder
A builder that allows more customization of the game window shown to the user before the RaylibHandle is created.
RaylibHandle
The main interface into the Raylib API.
RaylibThread
This token is used to ensure certain functions are only running on the same thread raylib was initialized from. This is useful for architectures like macos where cocoa can only be called from one thread.

Functions

init
Creates a RaylibBuilder for choosing window options before initialization.