RaylibBuilder

Struct RaylibBuilder 

pub struct RaylibBuilder { /* private fields */ }
A builder that allows more customization of the game window shown to the user before the RaylibHandle is created.

Implementations

Source

impl RaylibBuilder

pub fn fullscreen(&mut self) -> &mut RaylibBuilder

Sets the window to be fullscreen.

pub fn log_level(&mut self, level: TraceLogLevel) -> &mut RaylibBuilder

Set the builder’s log level.

pub fn resizable(&mut self) -> &mut RaylibBuilder

Sets the window to be resizable.

pub fn undecorated(&mut self) -> &mut RaylibBuilder

Sets the window to be undecorated (without a border).

pub fn transparent(&mut self) -> &mut RaylibBuilder

Sets the window to be transparent.

pub fn msaa_4x(&mut self) -> &mut RaylibBuilder

Hints that 4x MSAA (anti-aliasing) should be enabled. The system’s graphics drivers may override this setting.

pub fn vsync(&mut self) -> &mut RaylibBuilder

Hints that vertical sync (VSync) should be enabled. The system’s graphics drivers may override this setting.

pub fn width(&mut self, w: i32) -> &mut RaylibBuilder

Sets the window’s width.

pub fn height(&mut self, h: i32) -> &mut RaylibBuilder

Sets the window’s height.

pub fn size(&mut self, w: i32, h: i32) -> &mut RaylibBuilder

Sets the window’s width and height.

pub fn title(&mut self, text: &str) -> &mut RaylibBuilder

Sets the window title.

pub fn build(&self) -> (RaylibHandle, RaylibThread)

Builds and initializes a Raylib window.

Panics

Attempting to initialize Raylib more than once will result in a panic.