Tween

Struct Tween 

pub struct Tween { /* private fields */ }
A manager for a tween on a single f32 value.

Implementations

Source

impl Tween

pub fn new( easer: fn(f32, f32, f32, f32) -> f32, start_value: f32, end_value: f32, duration: f32, ) -> Tween

Creates a new Tween given the easing function, value bounds, and duration.

pub fn reset(&mut self)

Resets the tween to the beginning.

pub fn has_completed(&self) -> bool

Returns true if the tween has completed.

pub fn apply(&mut self, time_advance: f32) -> f32

Returns the new value after applying the tween, advancing time by time_advance.

pub fn reverse(&mut self)

Reverses the tween, adjusting the current time position such that it will retrace its steps so far.

pub fn current_time(&self) -> f32

Returns the current time position of the tween.

pub fn start_value(&self) -> f32

Returns the starting value of the tween.

pub fn end_value(&self) -> f32

Returns the ending value of the tween.

pub fn duration(&self) -> f32

Returns the duration of the tween.