#[repr(C)]pub struct AudioStream {
pub buffer: *mut rAudioBuffer,
pub processor: *mut rAudioProcessor,
pub sampleRate: u32,
pub sampleSize: u32,
pub channels: u32,
}Fields
buffer: *mut rAudioBufferprocessor: *mut rAudioProcessorsampleRate: u32sampleSize: u32channels: u32Trait Implementations
Sourceimpl<'a> AsMut<AudioStream> for AudioStream<'a>
impl<'a> AsMut<AudioStream> for AudioStream<'a>
Sourcefn as_mut(&mut self) -> &mut AudioStream
fn as_mut(&mut self) -> &mut AudioStream
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'aud> AsMut<AudioStream> for Sound<'aud>
impl<'aud> AsMut<AudioStream> for Sound<'aud>
Sourcefn as_mut(&mut self) -> &mut AudioStream
fn as_mut(&mut self) -> &mut AudioStream
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'a> AsRef<AudioStream> for AudioStream<'a>
impl<'a> AsRef<AudioStream> for AudioStream<'a>
Sourcefn as_ref(&self) -> &AudioStream
fn as_ref(&self) -> &AudioStream
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl<'aud> AsRef<AudioStream> for Sound<'aud>
impl<'aud> AsRef<AudioStream> for Sound<'aud>
Sourcefn as_ref(&self) -> &AudioStream
fn as_ref(&self) -> &AudioStream
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for AudioStream
impl Clone for AudioStream
Sourcefn clone(&self) -> AudioStream
fn clone(&self) -> AudioStream
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AudioStream
impl Debug for AudioStream
impl Copy for AudioStream