#[repr(C)]pub struct FilePathList {
pub capacity: u32,
pub count: u32,
pub paths: *mut *mut i8,
}Fields
capacity: u32count: u32paths: *mut *mut i8Trait Implementations
Sourceimpl AsMut<FilePathList> for DroppedFilePathList
impl AsMut<FilePathList> for DroppedFilePathList
Sourcefn as_mut(&mut self) -> &mut FilePathList
fn as_mut(&mut self) -> &mut FilePathList
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsMut<FilePathList> for FilePathList
impl AsMut<FilePathList> for FilePathList
Sourcefn as_mut(&mut self) -> &mut FilePathList
fn as_mut(&mut self) -> &mut FilePathList
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<FilePathList> for DroppedFilePathList
impl AsRef<FilePathList> for DroppedFilePathList
Sourcefn as_ref(&self) -> &FilePathList
fn as_ref(&self) -> &FilePathList
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AsRef<FilePathList> for FilePathList
impl AsRef<FilePathList> for FilePathList
Sourcefn as_ref(&self) -> &FilePathList
fn as_ref(&self) -> &FilePathList
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for FilePathList
impl Clone for FilePathList
Sourcefn clone(&self) -> FilePathList
fn clone(&self) -> FilePathList
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FilePathList
impl Debug for FilePathList
impl Copy for FilePathList