#[repr(C)]pub struct MaterialMap {
pub texture: Texture,
pub color: Color,
pub value: f32,
}Fields
texture: Texturecolor: Colorvalue: f32Trait Implementations
Sourceimpl AsMut<MaterialMap> for MaterialMap
impl AsMut<MaterialMap> for MaterialMap
Sourcefn as_mut(&mut self) -> &mut MaterialMap
fn as_mut(&mut self) -> &mut MaterialMap
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<MaterialMap> for MaterialMap
impl AsRef<MaterialMap> for MaterialMap
Sourcefn as_ref(&self) -> &MaterialMap
fn as_ref(&self) -> &MaterialMap
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for MaterialMap
impl Clone for MaterialMap
Sourcefn clone(&self) -> MaterialMap
fn clone(&self) -> MaterialMap
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MaterialMap
impl Debug for MaterialMap
impl Copy for MaterialMap