#[repr(C)]pub struct ModelAnimation {
pub boneCount: i32,
pub frameCount: i32,
pub bones: *mut BoneInfo,
pub framePoses: *mut *mut Transform,
pub name: [i8; 32],
}Fields
boneCount: i32frameCount: i32bones: *mut BoneInfoframePoses: *mut *mut Transformname: [i8; 32]Trait Implementations
Sourceimpl AsMut<ModelAnimation> for ModelAnimation
impl AsMut<ModelAnimation> for ModelAnimation
Sourcefn as_mut(&mut self) -> &mut ModelAnimation
fn as_mut(&mut self) -> &mut ModelAnimation
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsMut<ModelAnimation> for WeakModelAnimation
impl AsMut<ModelAnimation> for WeakModelAnimation
Sourcefn as_mut(&mut self) -> &mut ModelAnimation
fn as_mut(&mut self) -> &mut ModelAnimation
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<ModelAnimation> for ModelAnimation
impl AsRef<ModelAnimation> for ModelAnimation
Sourcefn as_ref(&self) -> &ModelAnimation
fn as_ref(&self) -> &ModelAnimation
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AsRef<ModelAnimation> for WeakModelAnimation
impl AsRef<ModelAnimation> for WeakModelAnimation
Sourcefn as_ref(&self) -> &ModelAnimation
fn as_ref(&self) -> &ModelAnimation
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for ModelAnimation
impl Clone for ModelAnimation
Sourcefn clone(&self) -> ModelAnimation
fn clone(&self) -> ModelAnimation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModelAnimation
impl Debug for ModelAnimation
impl Copy for ModelAnimation