#[repr(C)]pub struct RenderTexture {
pub id: u32,
pub texture: Texture,
pub depth: Texture,
}Fields
id: u32texture: Texturedepth: TextureTrait Implementations
Sourceimpl AsMut<RenderTexture> for RenderTexture2D
impl AsMut<RenderTexture> for RenderTexture2D
Sourcefn as_mut(&mut self) -> &mut RenderTexture
fn as_mut(&mut self) -> &mut RenderTexture
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsMut<RenderTexture> for WeakRenderTexture2D
impl AsMut<RenderTexture> for WeakRenderTexture2D
Sourcefn as_mut(&mut self) -> &mut RenderTexture
fn as_mut(&mut self) -> &mut RenderTexture
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<RenderTexture> for RenderTexture2D
impl AsRef<RenderTexture> for RenderTexture2D
Sourcefn as_ref(&self) -> &RenderTexture
fn as_ref(&self) -> &RenderTexture
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AsRef<RenderTexture> for WeakRenderTexture2D
impl AsRef<RenderTexture> for WeakRenderTexture2D
Sourcefn as_ref(&self) -> &RenderTexture
fn as_ref(&self) -> &RenderTexture
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for RenderTexture
impl Clone for RenderTexture
Sourcefn clone(&self) -> RenderTexture
fn clone(&self) -> RenderTexture
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RenderTexture
impl Debug for RenderTexture
impl Copy for RenderTexture