#[repr(C)]pub struct VrStereoConfig {
pub projection: [Matrix; 2],
pub viewOffset: [Matrix; 2],
pub leftLensCenter: [f32; 2],
pub rightLensCenter: [f32; 2],
pub leftScreenCenter: [f32; 2],
pub rightScreenCenter: [f32; 2],
pub scale: [f32; 2],
pub scaleIn: [f32; 2],
}Fields
projection: [Matrix; 2]viewOffset: [Matrix; 2]leftLensCenter: [f32; 2]rightLensCenter: [f32; 2]leftScreenCenter: [f32; 2]rightScreenCenter: [f32; 2]scale: [f32; 2]scaleIn: [f32; 2]Trait Implementations
Sourceimpl AsMut<VrStereoConfig> for VrStereoConfig
impl AsMut<VrStereoConfig> for VrStereoConfig
Sourcefn as_mut(&mut self) -> &mut VrStereoConfig
fn as_mut(&mut self) -> &mut VrStereoConfig
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<VrStereoConfig> for VrStereoConfig
impl AsRef<VrStereoConfig> for VrStereoConfig
Sourcefn as_ref(&self) -> &VrStereoConfig
fn as_ref(&self) -> &VrStereoConfig
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for VrStereoConfig
impl Clone for VrStereoConfig
Sourcefn clone(&self) -> VrStereoConfig
fn clone(&self) -> VrStereoConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VrStereoConfig
impl Debug for VrStereoConfig
impl Copy for VrStereoConfig