pub struct DroppedFilePathList(/* private fields */);Implementations
Sourceimpl DroppedFilePathList
impl DroppedFilePathList
Sourcepub unsafe fn unwrap(self) -> FilePathList
pub unsafe fn unwrap(self) -> FilePathList
Take the raw ffi type. Must manually free memory by calling the proper unload function
Sourceimpl DroppedFilePathList
impl DroppedFilePathList
Sourcepub fn to_raw(self) -> FilePathList
pub fn to_raw(self) -> FilePathList
returns the unwrapped raylib-sys object
Sourcepub unsafe fn from_raw(raw: FilePathList) -> DroppedFilePathList
pub unsafe fn from_raw(raw: FilePathList) -> DroppedFilePathList
converts raylib-sys object to a “safe” version. Make sure to call this function from the thread the resource was created.