pub fn get_monitor_name(monitor: i32) -> Result<String, IntoStringError>Expand description
Get name of monitor Only checks that monitor index is in range in debug mode
pub fn get_monitor_name(monitor: i32) -> Result<String, IntoStringError>Get name of monitor Only checks that monitor index is in range in debug mode