Vector2

Struct Vector2 

#[repr(C)]
pub struct Vector2 { pub x: f32, pub y: f32, }

Fields

x: f32y: f32

Implementations

Source

impl Vector2

pub const fn new(x: f32, y: f32) -> Vector2

Returns a new Vector2 with specified components.

pub const fn zero() -> Vector2

Returns a new Vector2 with both components set to zero.

pub const fn one() -> Vector2

Returns a new Vector2 with both components set to one.

pub fn length(&self) -> f32

Calculates the vector length.

pub fn length_sqr(&self) -> f32

Calculates the vector length square (**2);

pub fn dot(&self, v: Vector2) -> f32

Calculates the dot product with vector v.

pub fn distance_to(&self, v: Vector2) -> f32

Calculates the distance towards vector v.

pub fn angle_to(&self, v: Vector2) -> f32

Calculates the angle towards vector v in radians.

pub fn scale(&mut self, scale: f32)

Scales the vector by multiplying both components by scale.

pub fn scale_by(&self, scale: f32) -> Vector2

Returns a new Vector2 with components scaled by scale.

pub fn normalize(&mut self)

Normalizes the vector.

pub fn normalized(&self) -> Vector2

Returns a new Vector2 with normalized components from the current vector.

pub fn rotate(&mut self, angle: f32)

Rotates the vector by angle radians.

pub fn rotated(&self, angle: f32) -> Vector2

Returns a new Vector2 rotated by angle radians.

pub fn lerp(&self, v: Vector2, amount: f32) -> Vector2

Returns a new Vector2 with componenets linearly interpolated by amount towards vector v.

pub fn clamp(&self, num: Range<f32>) -> Vector2

Returns a new Vector2 with componenets clamp to a certain interval.