Model

Struct Model 

pub struct Model(/* private fields */);

Implementations

Source

impl Model

pub unsafe fn unwrap(self) -> Model

Take the raw ffi type. Must manually free memory by calling the proper unload function

Source

impl Model

pub fn to_raw(self) -> Model

returns the unwrapped raylib-sys object

pub unsafe fn from_raw(raw: Model) -> Model

converts raylib-sys object to a “safe” version. Make sure to call this function from the thread the resource was created.

Source

impl Model

pub unsafe fn make_weak(self) -> WeakModel