Module platform_sync

Module platform_sync 

🛡️ V-Shield Platform Sync

Sincronización de renderizado multiplataforma.

Maneja las diferencias entre X11, OpenGL, y otros backends para garantizar que los comandos de renderizado se ejecuten correctamente en cada frame.

Modos

  • X11: Termux-X11, Linux desktop → XFlush + XSync
  • OpenGL: Native GL → glFlush
  • Auto: Auto-detect por env var DISPLAY

Ejemplo

use v_shield::platform_sync::PlatformSync;

let mut sync = PlatformSync::new();
// ... al final de cada frame ...
sync.sync();

Structs

PlatformSync
Platform Sync - sincronización de frame multiplataforma

Enums

PlatformSyncMode
Modo de sincronización