WeakShader

Struct WeakShader 

pub struct WeakShader(/* private fields */);

Implementations

Source

impl WeakShader

pub unsafe fn unwrap(self) -> Shader

Take the raw ffi type. Must manually free memory by calling the proper unload function

Source

impl WeakShader

pub fn to_raw(self) -> Shader

returns the unwrapped raylib-sys object

pub unsafe fn from_raw(raw: Shader) -> WeakShader

converts raylib-sys object to a “safe” version. Make sure to call this function from the thread the resource was created.