pub struct AutomationEvent(/* private fields */);Implementations
Sourceimpl AutomationEvent
impl AutomationEvent
Sourcepub unsafe fn unwrap(self) -> AutomationEvent
pub unsafe fn unwrap(self) -> AutomationEvent
Take the raw ffi type. Must manually free memory by calling the proper unload function
Sourceimpl AutomationEvent
impl AutomationEvent
Sourcepub fn to_raw(self) -> AutomationEvent
pub fn to_raw(self) -> AutomationEvent
returns the unwrapped raylib-sys object
Sourcepub unsafe fn from_raw(raw: AutomationEvent) -> AutomationEvent
pub unsafe fn from_raw(raw: AutomationEvent) -> AutomationEvent
converts raylib-sys object to a “safe” version. Make sure to call this function from the thread the resource was created.