Material

Struct Material 

pub struct Material(/* private fields */);

Implementations

Source

impl Material

pub unsafe fn unwrap(self) -> Material

Take the raw ffi type. Must manually free memory by calling the proper unload function

Source

impl Material

pub fn to_raw(self) -> Material

returns the unwrapped raylib-sys object

pub unsafe fn from_raw(raw: Material) -> Material

converts raylib-sys object to a “safe” version. Make sure to call this function from the thread the resource was created.

Source

impl Material

pub unsafe fn make_weak(self) -> WeakMaterial

pub fn load_materials(filename: &str) -> Result<Vec<Material>, Error>