pub struct ModelAnimation(/* private fields */);Implementations
Sourceimpl ModelAnimation
impl ModelAnimation
Sourcepub unsafe fn unwrap(self) -> ModelAnimation
pub unsafe fn unwrap(self) -> ModelAnimation
Take the raw ffi type. Must manually free memory by calling the proper unload function
Sourceimpl ModelAnimation
impl ModelAnimation
Sourcepub fn to_raw(self) -> ModelAnimation
pub fn to_raw(self) -> ModelAnimation
returns the unwrapped raylib-sys object
Sourcepub unsafe fn from_raw(raw: ModelAnimation) -> ModelAnimation
pub unsafe fn from_raw(raw: ModelAnimation) -> ModelAnimation
converts raylib-sys object to a “safe” version. Make sure to call this function from the thread the resource was created.
Sourceimpl ModelAnimation
impl ModelAnimation
pub unsafe fn make_weak(self) -> WeakModelAnimation