pub struct RaylibThread(/* private fields */);Expand description
This token is used to ensure certain functions are only running on the same thread raylib was initialized from. This is useful for architectures like macos where cocoa can only be called from one thread.