Wave

Struct Wave 

pub struct Wave<'a>(/* private fields */);

Implementations

Source

impl<'a> Wave<'a>

pub unsafe fn unwrap(self) -> Wave

Take the raw ffi type. Must manually free memory by calling the proper unload function

Source

impl<'aud> Wave<'aud>

pub fn frame_count(&self) -> u32

pub fn sample_rate(&self) -> u32

pub fn sample_size(&self) -> u32

pub fn channels(&self) -> u32

pub unsafe fn inner(self) -> Wave

pub fn is_wave_valid(&self) -> bool

pub fn export(&self, filename: impl AsRef<Path>) -> bool

Export wave file. Extension must be .wav or .raw

pub fn format(&mut self, sample_rate: i32, sample_size: i32, channels: i32)

Converts wave data to desired format.

pub fn crop(&mut self, init_sample: i32, final_sample: i32)

Crops a wave to defined sample range.

pub fn load_samples(&self) -> WaveSamples

Load samples data from wave as a floats array NOTE 1: Returned sample values are normalized to range [-1..1] NOTE 2: Sample data allocated should be freed with UnloadWaveSamples()