Module text

Module text 

Text and Font related functions Text manipulation functions are super unsafe so use rust String functions

Structs

Font
GlyphInfo
RSliceGlyphInfo
WeakFont

Traits

RaylibFont

Functions

gen_image_font_atlas
Generates image font atlas using chars info. Sets a pointer to an array of rectangles raylib allocated that MUST manually be freed. Good luck freeing it safely though ;)