pub struct WeakRenderTexture2D(/* private fields */);Implementations
Sourceimpl WeakRenderTexture2D
impl WeakRenderTexture2D
Sourcepub unsafe fn unwrap(self) -> RenderTexture
pub unsafe fn unwrap(self) -> RenderTexture
Take the raw ffi type. Must manually free memory by calling the proper unload function
Sourceimpl WeakRenderTexture2D
impl WeakRenderTexture2D
Sourcepub fn to_raw(self) -> RenderTexture
pub fn to_raw(self) -> RenderTexture
returns the unwrapped raylib-sys object
Sourcepub unsafe fn from_raw(raw: RenderTexture) -> WeakRenderTexture2D
pub unsafe fn from_raw(raw: RenderTexture) -> WeakRenderTexture2D
converts raylib-sys object to a “safe” version. Make sure to call this function from the thread the resource was created.