Module callbacks

Module callbacks 

Structs

AudioStreamProcessorCallback
This struct encapsulates a rust callback and guarantees the lifetime to be long enough (’a) (once get_as_user_data is called, it the struct should not be moved again! -> use Pin<..>)
SetLogError

Enums

TraceLogLevel

Functions

attach_audio_stream_processor_to_music
custom_trace_log_callback
set_audio_stream_callback
Audio thread callback to request new data
set_load_file_data_callback
Set custom file binary data loader
set_load_file_text_callback
Set custom file text data loader
set_save_file_data_callback
Set custom file binary data saver
set_save_file_text_callback
Set custom file text data saver
set_trace_log_callback
Set custom trace log