pub fn set_load_file_data_callback<'b>(
cb: fn(&str) -> Vec<u8>,
) -> Result<(), SetLogError<'b>>Expand description
Set custom file binary data loader
Whatever you return from your callback will be intentionally leaked as Raylib is relied on to free it.