pub fn set_load_file_text_callback<'a>(
cb: fn(&str) -> String,
) -> Result<(), SetLogError<'a>>Expand description
Set custom file text data loader
Whatever you return from your callback will be intentionally leaked as Raylib is relied on to free it.