Module core
v_
shield
0.2.0
Module core
Module Items
Structs
Functions
In crate v_
shield
v_shield
Module
core
Structs

Raylib
Builder
A builder that allows more customization of the game window shown to the user before the
RaylibHandle
is created.
Raylib
Handle
The main interface into the Raylib API.
Raylib
Thread
This token is used to ensure certain functions are only running on the same thread raylib was initialized from. This is useful for architectures like macos where cocoa can only be called from one thread.
Functions

init
Creates a
RaylibBuilder
for choosing window options before initialization.