Module misc

Module misc 

Useful functions that don’t fit anywhere else

Structs

RandSeqIterator
RandomSequence
Struct for holding the result of RaylibHandle::load_random_sequence. This is a thin wrapper for an array of i32. The reason it exists is because Raylib expects you to unload the sequence it creates manually, and this struct does it for you.

Traits

AsF32

Functions

open_url
Open URL with default system browser (if available)