🛡️ V-Shield Platform Sync
Sincronización de renderizado multiplataforma.
Maneja las diferencias entre X11, OpenGL, y otros backends para garantizar que los comandos de renderizado se ejecuten correctamente en cada frame.
Modos
X11: Termux-X11, Linux desktop → XFlush + XSyncOpenGL: Native GL → glFlushAuto: Auto-detect por env varDISPLAY
Ejemplo
use v_shield::platform_sync::PlatformSync;
let mut sync = PlatformSync::new();
// ... al final de cada frame ...
sync.sync();Structs
- Platform
Sync - Platform Sync - sincronización de frame multiplataforma
Enums
- Platform
Sync Mode - Modo de sincronización