Text and Font related functions Text manipulation functions are super unsafe so use rust String functions
Structs
Traits
Functions
- gen_
image_ font_ atlas - Generates image font atlas using
charsinfo. Sets a pointer to an array of rectangles raylib allocated that MUST manually be freed. Good luck freeing it safely though ;)