Window manipulation functions
Structs
Functions
- get_
camera_ matrix - Returns camera transform matrix (view matrix)
- get_
camera_ matrix2D - Returns camera 2D transform matrix (view matrix)
- get_
current_ monitor - get_
current_ monitor_ index - get_
monitor_ count - Get number of connected monitors
- get_
monitor_ height - Get height of monitor Only checks that monitor index is in range in debug mode
- get_
monitor_ info - Gets the attributes of the monitor as well as the name fails if monitor name is not a utf8 string
- get_
monitor_ name - Get name of monitor Only checks that monitor index is in range in debug mode
- get_
monitor_ physical_ height - Get physical height of monitor Only checks that monitor index is in range in debug mode
- get_
monitor_ physical_ width - Get physical width of monitor Only checks that monitor index is in range in debug mode
- get_
monitor_ position - Get position of monitor Only checks that monitor index is in range in debug mode
- get_
monitor_ refresh_ rate - Get specified monitor refresh rate
- get_
monitor_ width - Get width of monitor Only checks that monitor index is in range in debug mode